==> haskell-th-lift-instances-0.1.20-47-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift-instances
version:              0.1.20
visibility:           public
id:                   th-lift-instances-0.1.20-IIA6wf2jfwL4V6JOBckTBp
key:                  th-lift-instances-0.1.20-IIA6wf2jfwL4V6JOBckTBp
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  99ed4f3a378a2c44292d067da79d67fc
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-lift-instances-0.1.20
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-lift-instances-0.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift-instances
hs-libraries:         HSth-lift-instances-0.1.20-IIA6wf2jfwL4V6JOBckTBp
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    template-haskell-2.18.0.0 text-1.2.5.0
    th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY transformers-0.5.6.2
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.20-49-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift-instances
version:              0.1.20
visibility:           public
id:                   th-lift-instances-0.1.20-7UUlrTsIDWL3XQkjxcQngm
key:                  th-lift-instances-0.1.20-7UUlrTsIDWL3XQkjxcQngm
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  ee83d55d389a71b498b1d21efed807fc
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-lift-instances-0.1.20
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-lift-instances-0.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift-instances
hs-libraries:         HSth-lift-instances-0.1.20-7UUlrTsIDWL3XQkjxcQngm
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    template-haskell-2.18.0.0 text-1.2.5.0
    th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY transformers-0.5.6.2
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
